# Description of the test data provenance.

## dda_test.d (Bruker raw TDF)

This file was synthetically generated by Sander Willems and copied from the timsrust_pyo3 repo.

## test.ms2 (Bruker raw miniTDF)

This file was generated by Sander Willems and copied from the timsrust_pyo3 repo.

## test.mzml

Converted with tdf2mzml from dda_test.d.

## test.mgf

Manually fabricated spectrum.

## small.raw

From the [mzdata repository](https://github.com/mobiusklein/mzdata/blob/v0.27.0/test/data/small.RAW).
